@@ -28,6 +28,16 @@ class PermissionConf(AppConf):
     DEFAULT_CPL_CHANGE_PERMISSION = True
     DEFAULT_CPL_DELETE_PERMISSION = False
 
+    DEFAULT_GIPL_ANY_PERMISSION = False
+    DEFAULT_GIPL_ADD_PERMISSION = True
+    DEFAULT_GIPL_CHANGE_PERMISSION = True
+    DEFAULT_GIPL_DELETE_PERMISSION = False
+
+    DEFAULT_SPL_ANY_PERMISSION = False
+    DEFAULT_SPL_ADD_PERMISSION = True
+    DEFAULT_SPL_CHANGE_PERMISSION = True
+    DEFAULT_SPL_DELETE_PERMISSION = False
+
     AUTODISCOVER_ENABLE = True
     AUTODISCOVER_MODULE_NAME = 'perms'
     AUTODISCOVER_VARIABLE_NAME = 'PERMISSION_LOGICS'
