@@ -4,16 +4,30 @@
 __author__ = 'Alisue <lambdalisue@hashnote.net>'
 
 
-def create_user(username):
+def create_user(username, **kwargs):
     from django.contrib.auth.models import User
     user = User.objects.create_user(
             username=username,
             email="%s@test.com" % username,
-            password="password"
+            password="password",
         )
+    # attribute assignment
+    for key, value in kwargs.items():
+        user.__dict__[key] = value
     user.save()
     return user
 
+def create_group(name, user=None):
+    from django.contrib.auth.models import Group
+    group = Group.objects.create(
+            name=name,
+        )
+    if user is not None:
+        user.groups.add(group)
+        user.save()
+    group.save()
+    return group
+
 def create_article(title, user=None):
     import datetime
     from permission.tests.models import Article
